@@ -2,6 +2,7 @@ from __future__ import print_function
 
 import os
 from copy import copy
+from locale import LC_CTYPE, Error, getlocale, setlocale
 
 from enigma import eServiceReference, eTimer, iPlayableService
 from Components.ActionMap import ActionMap
@@ -389,9 +390,16 @@ class YouTubeMain(Screen):
 		self.yts = [{}]
 		self.onLayoutFinish.append(self.layoutFinish)
 		self.onClose.append(self.cleanVariables)
+		self.locale = getlocale(LC_CTYPE)
+		if self.locale[0] is not None:
+			# Workaround to fix ssl error unable to find public key parameters with some (turkish) LC_CTYPE
+			try:
+				setlocale(LC_CTYPE, locale=(None, None))
+			except Error as e:
+				print('[YouTube] Error on set locale:', e)
+				self.locale = (None, None)
 		for p in plugins.getPlugins(where=PluginDescriptor.WHERE_MENU):
-			# TRANSLATORS: Don't translate this! It is used as a variable, so it must be equal to the translation in the plugin!
-			if p.name == _('ServiceApp'):
+			if 'ServiceApp' in p.path:
 				break
 		else:
 			config.plugins.YouTube.player.value = '4097'
@@ -434,6 +442,8 @@ class YouTubeMain(Screen):
 		self.thumbnails = None
 		self.ytapi = None
 		self.ytdl = None
+		if self.locale[0] is not None:
+			setlocale(LC_CTYPE, locale=self.locale)
 
 	def showButtons(self):
 		self['red'].show()
@@ -1504,8 +1514,7 @@ class YouTubeSetup(ConfigListScreen, Screen):
 			config.plugins.YouTube.VirtualKeyBoard,
 			_('You can choose what style of VirtualKeyBoard to use it.\nYouTube OR Image (VirtualKeyBoard).')))
 		for p in plugins.getPlugins(where=PluginDescriptor.WHERE_MENU):
-			# TRANSLATORS: Don't translate this! It is used as a variable, so it must be equal to the translation in the plugin!
-			if p.name == _('ServiceApp'):  # pragma: no cover
+			if 'ServiceApp' in p.path:  # pragma: no cover
 				self.list.append(getConfigListEntry(_('Media player:'),
 					config.plugins.YouTube.player,
 					_('Specify the player which will be used for YouTube media playback.')))
